package com.example.matule.presentation.split1.signIn

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import cafe.adriel.voyager.core.model.rememberScreenModel
import cafe.adriel.voyager.core.screen.Screen
import cafe.adriel.voyager.navigator.LocalNavigator
import cafe.adriel.voyager.navigator.Navigator
import com.example.matule.presentation.split1.home.HomeScreen
import kotlin.math.tanh


class SignInScreen: Screen{
    @Composable
    override fun Content() {
        val screenModel = rememberScreenModel { SignInScreenModel() }
        val navigator = LocalNavigator.current
        SignInContent(screenModel, navigator!!)
    }

    @Composable
    fun SignInContent(screenModel: SignInScreenModel, localNavigator: Navigator){
        val signInState = screenModel.signInScreenState.collectAsState()
        if(signInState.value.isAuthorize){
            localNavigator.push(HomeScreen())
            signInState.value.isAuthorize = false
        }

        Column {
            OutlinedTextField(
                value = signInState.value.email,
                onValueChange = {
                    screenModel.setEmail(it)

                },
                label = { Text("Email") }

            )
            OutlinedTextField(
                value = signInState.value.password,
                onValueChange = {
                    screenModel.setPassword(it)
                },
                visualTransformation = PasswordVisualTransformation(),
                label = { Text("Password") }

            )
            Button(onClick = { screenModel.auth() }) {
                Text("Auth")
                if (!signInState.value.isAuthorize) return@Button CircularProgressIndicator(
                    modifier = Modifier.width(30.dp),
                    color = MaterialTheme.colorScheme.secondary,
                    trackColor = MaterialTheme.colorScheme.surfaceVariant
                )
            }


        }
    }
}